# eve-rights

Handle per-item rights in a python-eve application

## Description

Eve-Rights is allowing you to handle basics ACL on your eve application by adding two fields on your resource :

1. Who can read ?
2. Who can right ?

The only thing you need is to have an account resource named how you want.

## Configuration

soon
